WoHttpResponse class

Internal normalized HTTP response model.

Constructors

WoHttpResponse({required int statusCode, required dynamic body, required Map<String, String> headers, required WoHttpRequest request, Object? exception})
const

Properties

body → dynamic
Decoded body (JSON map/list/string/null).
final
errorType WoHttpErrorType
Best-effort mapping from status/exception to WoHttpErrorType.
no setter
exception Object?
Optional low-level exception captured by the client.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Response headers.
final
isSuccess bool
True when statusCode is in the 2xx range.
no setter
request WoHttpRequest
Original request that produced this response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP status code. 0 is used for transport-level failures.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited